:html_theme.sidebar_secondary.remove: true

.. _install_pip:

Installing from PyPI
~~~~~~~~~~~~~~~~~~~~

EEGDash can be installed via pip from `PyPI <eegdash-pypi_>`_.

.. note::
    We recommend the most updated version of pip to install from PyPI.

Below are the installation commands for the most common use cases.

.. code-block:: shell

   pip install eegdash

This will install the eegdash package and its dependencies.

.. include:: /links.inc
